Index: lib/src/source/cached.dart |
diff --git a/lib/src/source/cached.dart b/lib/src/source/cached.dart |
index e492f54c36af40207284c9afd8a14734c0c66b9d..8a40bc3bcba4864c4e238afbacb75dc4250740e5 100644 |
--- a/lib/src/source/cached.dart |
+++ b/lib/src/source/cached.dart |
@@ -12,17 +12,18 @@ import '../pubspec.dart'; |
import '../source.dart'; |
import '../utils.dart'; |
/// Base class for a [Source] that installs packages into pub's [SystemCache]. |
/// |
/// A source should be cached if it requires network access to retrieve |
/// packages or the package needs to be "frozen" at the point in time that it's |
/// installed. (For example, Git packages are cached because installing from |
/// the same repo over time may yield different commits.) |
-abstract class CachedSource extends Source { |
+abstract class CachedSource extends BoundSource { |
/// The root directory of this source's cache within the system cache. |
/// |
/// This shouldn't be overridden by subclasses. |
- String get systemCacheRoot => path.join(systemCache.rootDir, name); |
+ String get systemCacheRoot => path.join(systemCache.rootDir, source.name); |
/// If [id] is already in the system cache, just loads it from there. |
/// |
@@ -12,17 +12,18 @@ import '../pubspec.dart'; |
import '../source.dart'; |
import '../utils.dart'; |
-/// Base class for a [Source] that installs packages into pub's [SystemCache]. |
+/// Base class for a [BoundSource] that installs packages into pub's |
+/// [SystemCache]. |
/// |
/// A source should be cached if it requires network access to retrieve |